> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Diff Pressure Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on PIC32
```
#include "diff_pressure_hw.h"

sbit DIFF_PRESSURE_CS         at RC2_bit;
sbit DIFF_PRESSURE_CS_DIR     at TRISC2_bit;
sbit DIFF_PRESSURE_RDY        at RF2_bit;
sbit DIFF_PRESSURE_RDY_DIR    at TRISF2_bit;

void system_setup( void )
{
    //GPIOs
        DIFF_PRESSURE_CS_DIR  = 0;
        DIFF_PRESSURE_RDY_DIR = 1;

    //UART
    UART2_Init( 9600 );
    Delay_ms(200);
    UART2_Write_Text( "UART Initialized\r\n" );

        // SPI
        SPI3_Init_Advanced( _SPI_MASTER, _SPI_8_BIT, 1, _SPI_SS_DISABLE,
                    _SPI_DATA_SAMPLE_END, _SPI_CLK_IDLE_LOW,
                    _SPI_IDLE_2_ACTIVE );
    Delay_ms(200);
    UART2_Write_Text( "SPI Initialized\r\n" );

    //Diff Pressure Click
    diff_pressure_init();
    UART2_Write_Text( "Diff Pressure Click Initialized\r\n" );

}

```

```

void main()
{
    //Local Declarations
    int32_t buffer = 0;
    char uart_text[20] = { 0 };
    float difference = 0.;


        system_setup();

        while (1)
        {
            if (    diff_pressure_read_adc( &buffer ) == OK )
            {
                LongToStr( buffer, uart_text );
                UART2_Write_Text( "ADC Value: " );
                Ltrim( uart_text );
                UART2_Write_Text( uart_text );
                UART2_Write_Text( "\r\n" );
                difference = diff_pressure_get_kpa_difference( buffer );
                sprintf( uart_text, "KPA Difference: %.2f", difference );
                UART2_Write_Text( uart_text );
                UART2_Write_Text( "\r\n" );
                Delay_ms( 100 );
                buffer = 0;
            }
            else if ( diff_pressure_read_adc( &buffer ) == OVH )
                UART2_Write_Text( "Overflow happened\r\n" );
            else if ( diff_pressure_read_adc( &buffer ) == OVL )
                UART2_Write_Text( "Underflow happened\r\n" );
        }

}

```

